powered by
Gets random order statistics from a cauchy distribution
order_rcauchy(draw_size = 1, location = 0, scale = 1, k = 1, n = 1)
- The size of the output sample
- The location parameter in the cauchy distribution
- The scale parameter in the cauchy distribution
- The Kth smallest value from a sample
- The size of the sample to compute the order statistic from
A vector of random order statistic variables from a cauchy distribution
order_rcauchy(10, 0, 1, 100, 10000)
Run the code above in your browser using DataLab