Learn R Programming

orderstats (version 0.1.0)

order_rchisq: Gets random order statistics from a chi-square distribution

Description

Gets random order statistics from a chi-square distribution

Usage

order_rchisq(draw_size, df, k, n)

Arguments

draw_size

- The size of the output sample

df

- The degrees of the chi-square distribution

k

- The Kth smallest value from a sample

n

- The size of the sample to compute the order statistic from

Value

A vector of random order statistic variables from a chi-square distribution

Examples

Run this code
order_rchisq(10, 1, 100, 10000)

Run the code above in your browser using DataLab