powered by
Gets random order statistics from a gamma distribution
order_rgamma(draw_size, shape, scale, k, n)
- The size of the output sample
- The shape parameter in the gamma distribution
- The scale parameter in the gamma distribution
- The Kth smallest value from a sample
- The size of the sample to compute the order statistic from
A vector of random order statistic variables from a gamma distribution
order_rgamma(10, 20, 2, 100, 10000)
Run the code above in your browser using DataLab