Learn R Programming

orderstats (version 0.1.0)

order_rlogis: Gets random order statistics from a logistic distribution

Description

Gets random order statistics from a logistic distribution

Usage

order_rlogis(draw_size, location, scale, k, n)

Arguments

draw_size

- The size of the output sample

location

- The location parameter in the logistic distribution

scale

- The scale parameter in the logistic distribution

k

- The Kth smallest value from a sample

n

- The size of the sample to compute the order statistic from

Value

A vector of random order statistic variables from a logistic distribution

Examples

Run this code
order_rlogis(10, 0, 1, 100, 10000)

Run the code above in your browser using DataLab