powered by
Gets random order statistics from a chi-square distribution
order_rchisq(draw_size, df, k, n)
- The size of the output sample
- The degrees of the chi-square distribution
- The Kth smallest value from a sample
- The size of the sample to compute the order statistic from
A vector of random order statistic variables from a chi-square distribution
order_rchisq(10, 1, 100, 10000)
Run the code above in your browser using DataLab