powered by
Gets random order statistics from a logistic distribution
order_rlogis(draw_size, location, scale, k, n)
- The size of the output sample
- The location parameter in the logistic distribution
- The scale parameter in the logistic distribution
- The Kth smallest value from a sample
- The size of the sample to compute the order statistic from
A vector of random order statistic variables from a logistic distribution
order_rlogis(10, 0, 1, 100, 10000)
Run the code above in your browser using DataLab